@@ -1,6 +1,8 @@
 # --
 # Kernel/Output/HTML/LayoutAJAX.pm - provides generic HTML output
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: LayoutAJAX.pm,v 1.28 2010-08-31 09:26:00 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,17 +14,8 @@ package Kernel::Output::HTML::LayoutAJAX;
 use strict;
 use warnings;
 
-=head1 NAME
-
-Kernel::Output::HTML::LayoutAJAX - all AJAX-related HTML functions
-
-=head1 SYNOPSIS
-
-All AJAX-related HTML functions
-
-=head1 PUBLIC INTERFACE
-
-=over 4
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.28 $) [1];
 
 =item BuildSelectionJSON()
 
@@ -55,30 +48,14 @@ sub BuildSelectionJSON {
         my %Param = %{$Data};
 
         # check needed stuff
-        for (qw(Name)) {
+        for (qw(Name Data)) {
             if ( !defined $Param{$_} ) {
-                $Self->{LogObject}->Log(
-                    Priority => 'error',
-                    Message  => "Need $_!"
-                );
+                $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
                 return;
             }
         }
 
-        if ( !defined( $Param{Data} ) ) {
-            if ( !$Param{PossibleNone} ) {
-                $Self->{LogObject}->Log(
-                    Priority => 'error',
-                    Message  => "Need Data!"
-                );
-                return;
-            }
-            $DataHash{''} = '-';
-        }
-        elsif ( ref $Param{Data} eq '' ) {
-            $DataHash{ $Param{Name} } = $Param{Data};
-        }
-        elsif ( defined $Param{KeepData} && $Param{KeepData} ) {
+        if ( ref $Param{Data} eq '' ) {
             $DataHash{ $Param{Name} } = $Param{Data};
         }
         else {
@@ -111,24 +88,15 @@ sub BuildSelectionJSON {
                     if ( defined $Row->{Value} ) {
                         $Value = $Row->{Value};
                     }
-
-                    # DefaultSelected parameter for JavaScript New Option
-                    my $DefaultSelected = Kernel::System::JSON::False();
-
-                    # to set a disabled option (Disabled is not included in JavaScript New Option)
-                    my $Disabled = Kernel::System::JSON::False();
-
+                    my $SelectedDisabled = Kernel::System::JSON::False();
                     if ( $Row->{Selected} ) {
-                        $DefaultSelected = Kernel::System::JSON::True();
+                        $SelectedDisabled = Kernel::System::JSON::True();
                     }
                     elsif ( $Row->{Disabled} ) {
-                        $DefaultSelected = Kernel::System::JSON::False();
-                        $Disabled        = Kernel::System::JSON::True();
+                        $SelectedDisabled = Kernel::System::JSON::False();
                     }
 
-                    # Selected parameter for JavaScript NewOption
-                    my $Selected = $DefaultSelected;
-                    push @DataArray, [ $Key, $Value, $DefaultSelected, $Selected, $Disabled ];
+                    push @DataArray, [ $Key, $Value, $SelectedDisabled, $SelectedDisabled ];
                 }
                 $DataHash{ $AttributeRef->{name} } = \@DataArray;
             }
@@ -141,15 +109,3 @@ sub BuildSelectionJSON {
 }
 
 1;
-
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
