@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/Ticket/Event/Test.pm - test event module
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: Test.pm,v 1.11 2010-05-19 07:08:18 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Ticket::Event::Test;
@@ -11,10 +14,8 @@ package Kernel::System::Ticket::Event::Test;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::Log',
-    'Kernel::System::Ticket',
-);
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.11 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,6 +24,11 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # get needed objects
+    for (qw(ConfigObject TicketObject LogObject UserObject CustomerUserObject SendmailObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
     return $Self;
 }
 
@@ -32,37 +38,23 @@ sub Run {
     # check needed stuff
     for (qw(Data Event Config)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
     for (qw(TicketID)) {
         if ( !$Param{Data}->{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_ in Data!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_ in Data!" );
             return;
         }
     }
 
     if ( $Param{Event} eq 'TicketCreate' ) {
-
-        # get ticket object
-        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-
-        my %Ticket = $TicketObject->TicketGet(
-            TicketID      => $Param{Data}->{TicketID},
-            DynamicFields => 0,
-        );
-
+        my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{Data}->{TicketID} );
         if ( $Ticket{State} eq 'Test' ) {
 
             # do some stuff
-            $TicketObject->HistoryAdd(
+            $Self->{TicketObject}->HistoryAdd(
                 TicketID     => $Param{Data}->{TicketID},
                 CreateUserID => $Param{UserID},
                 HistoryType  => 'Misc',
@@ -71,19 +63,11 @@ sub Run {
         }
     }
     elsif ( $Param{Event} eq 'TicketQueueUpdate' ) {
-
-        # get ticket object
-        my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-
-        my %Ticket = $TicketObject->TicketGet(
-            TicketID      => $Param{Data}->{TicketID},
-            DynamicFields => 0,
-        );
-
+        my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{Data}->{TicketID} );
         if ( $Ticket{Queue} eq 'Test' ) {
 
             # do some stuff
-            $TicketObject->HistoryAdd(
+            $Self->{TicketObject}->HistoryAdd(
                 TicketID     => $Param{Data}->{TicketID},
                 CreateUserID => $Param{UserID},
                 HistoryType  => 'Misc',
@@ -91,7 +75,6 @@ sub Run {
             );
         }
     }
-
     return 1;
 }
 
