@@ -1,19 +1,24 @@
 #!/bin/sh
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Cron.sh - start|stop OTRS Cronjobs
+# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
 # --
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# $Id: Cron.sh,v 1.19 2009-02-26 11:01:01 tr Exp $
+# --
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU AFFERO General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# You should have received a copy of the GNU Affero General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 CURRENTUSER=`whoami`
@@ -38,8 +43,9 @@ fi
 # find otrs root
 cd "`dirname $0`/../"
 OTRS_HOME="`pwd`"
+cd -
 
-#OTRS_ROOT=/opt/otrs
+#OTRS_ROOT=/opt/OpenTRS
 if test -e $OTRS_HOME/var/cron; then
     OTRS_ROOT=$OTRS_HOME
 else
@@ -51,6 +57,9 @@ fi
 CRON_DIR=$OTRS_ROOT/var/cron
 CRON_TMP_FILE=$OTRS_ROOT/var/tmp/otrs-cron-tmp.$$
 
+echo "Cron.sh - start/stop OTRS cronjobs - <\$Revision: 1.19 $> "
+echo "Copyright (C) 2001-2009 OTRS AG, http://otrs.org/"
+
 #
 # main part
 #
@@ -59,12 +68,12 @@ case "$1" in
     # start
     # ------------------------------------------------------
     start)
-        # add -u to cron user if user exists
+        # add -u to cron user if exits
         if test -n "$CRON_USER"; then
             CRON_USER=" -u $CRON_USER"
         fi
 
-        if mkdir -p $CRON_DIR; cd $CRON_DIR && ls -d * | grep -Ev "(\.(dist|rpm|bak|backup|custom_backup|save|swp)|\~)$" | xargs cat > $CRON_TMP_FILE && crontab $CRON_USER $CRON_TMP_FILE; then
+        if mkdir -p $CRON_DIR; cd $CRON_DIR && ls -d * | grep -v '.dist'| grep -v '.rpm'| grep -v CVS | xargs cat > $CRON_TMP_FILE && crontab $CRON_USER $CRON_TMP_FILE; then
 
             rm -rf $CRON_TMP_FILE
             echo "(using $OTRS_ROOT) done";
@@ -78,7 +87,7 @@ case "$1" in
     # stop
     # ------------------------------------------------------
     stop)
-        # add -u to cron user if user exists
+        # add -u to cron user if exits
         if test -n "$CRON_USER"; then
             CRON_USER=" -u $CRON_USER"
         fi
@@ -102,16 +111,6 @@ case "$1" in
     # Usage
     # ------------------------------------------------------
     *)
-    cat - <<HELP
-
-Manage OTRS cron jobs.
-
-Usage:
- Cron.sh [action]
-
-Arguments:
- [action]                      - 'start', 'stop' or 'restart' - activate or deactivate OTRS cron jobs.
-HELP
-
+    echo "Usage: $0 {start|stop|restart}"
     exit 1
 esac
