@@ -1,9 +1,12 @@
 // --
-// Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+// Core.UI.Dialog.js - Dialogs
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// --
+// $Id: Core.UI.Dialog.js,v 1.31.2.1 2011-03-18 06:35:04 mp Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -12,114 +15,64 @@ var Core = Core || {};
 Core.UI = Core.UI || {};
 
 /**
- * @namespace Core.UI.Dialog
- * @memberof Core.UI
- * @author OTRS AG
+ * @namespace
+ * @exports TargetNS as Core.UI.Dialog
  * @description
  *      Contains the code for the different dialogs.
  */
 Core.UI.Dialog = (function (TargetNS) {
-    /**
-     * @private
-     * @name DialogCounter
-     * @memberof Core.UI.Dialog
-     * @member {Number}
-     * @description
-     *      Number of used/opened dialogs on a page. Used to restore the correct HTML backup after dialog is closed.
-     */
-    var DialogCounter = 1;
 
     /*
      * check dependencies first
      */
-    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI draggable')) {
-        return false;
+    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI dialog')) {
+        return;
     }
     if (!Core.Debug.CheckDependency('Core.UI.Dialog', 'Core.Config', 'Core.Config')) {
-        return false;
-    }
-    if (!Core.Debug.CheckDependency('Core.UI.Dialog', 'Core.UI.InputFields', 'Core.UI.InputFields')) {
-        return false;
+        return;
     }
 
     /**
-     * @private
-     * @name AdjustScrollableHeight
-     * @memberof Core.UI.Dialog
      * @function
-     * @param {Boolean} AllowAutoGrow - If AllowAutoGrow is set, auto-resizing should be possible.
-     * @description
-     *      Adjusts the scrollable inner container of the dialog after every resizing.
+     * @private
+     * @return nothing
+     * @description Adjusts the scrollable inner container of the dialog after every resizing.
      */
-    function AdjustScrollableHeight(AllowAutoGrow) {
+    function AdjustScrollableHeight() {
         // Check window height and adjust the scrollable height of InnerContent
         // Calculation:
         // Window height
-        // - top margin of dialog twice (for top and bottom) - only use this for big dialog windows
+        // - top margin of dialog twice (for top and bottom)
         // - some static pixels for Header and Footer of dialog
         var ContentScrollHeight = 0,
             WindowHeight = $(window).height(),
             WindowScrollTop = $(window).scrollTop(),
-            DialogTopMargin = $('.Dialog:visible').offset().top,
-            DialogHeight = $('.Dialog:visible').height();
+            DialogTopMargin = $('.Dialog:visible').offset().top;
 
-        // if dialog height is more than 300px recalculate width of InnerContent to make it scrollable
-        // if dialog is smaller than 300px this is not necessary
-        // if AllowAutoGrow is set, auto-resizing should be possible
-        // if in a mobile environment and a small screen, use as much window height as possible
-        if ($('.Dialog:visible').hasClass('Fullsize')) {
-            ContentScrollHeight = WindowHeight - 80;
-        }
-        else if (AllowAutoGrow || DialogHeight > 300) {
-            ContentScrollHeight = WindowHeight - ((DialogTopMargin - WindowScrollTop) * 2) - 100;
-        }
-        else {
-            ContentScrollHeight = 200;
-        }
+        ContentScrollHeight = WindowHeight - ((DialogTopMargin - WindowScrollTop) * 2) - 100;
         $('.Dialog:visible .Content .InnerContent').css('max-height', ContentScrollHeight);
     }
 
     /**
-     * @private
-     * @name FocusFirstElement
-     * @memberof Core.UI.Dialog
      * @function
-     * @description
-     *      Focuses the first element within the dialog.
+     * @private
+     * @return nothing
+     * @description Focuses the first element within the dialog.
      */
     function FocusFirstElement() {
-        var $FirstElement = $('div.Dialog:visible .Content')
-                .find('a:visible, input:visible, textarea:visible, select:visible, button:visible')
-                .filter(':first'),
-            $FocusField;
-
-        if (!$FirstElement || !$FirstElement.length || $('div.Dialog:visible').find('.OTRSBusinessRequiredDialog').length) {
-            return;
-        }
-
-        // If first element is modernized input field, prepend a semi-hidden text field and set focus on it instead.
-        //   This will prevent automatic expansion of the input field, but still move tab index to the dialog and allow
-        //   for keyboard navigation in it. See bug#12681 for more information.
-        if ($FirstElement.hasClass('InputField_Search')) {
-            $FocusField = $('<input/>')
-                .addClass('FocusField')
-                .insertBefore($FirstElement);
-            $FocusField.focus();
-        }
-        else {
-            $FirstElement.focus();
-        }
+        $('div.Dialog:visible .Content')
+            .find('a:visible, input:visible, textarea:visible, select:visible, button:visible')
+            .filter(':first')
+            .focus(1);
     }
 
     /**
-     * @private
-     * @name InitKeyEvent
-     * @memberof Core.UI.Dialog
      * @function
-     * @param {Boolean} CloseOnEscape - If set to true, the escape key is checked for closing the dialog.
-     * @description
-     *      Initializes the key event logger for the dialog.
-     *      Must be unbinded when closing the dialog.
+     * @private
+     * @param CloseOnEscape If set to true, the escape key is checked for closing the dialog.
+     * @return nothing
+     * @description Initializes the key event logger for the dialog.
+     *              Must be unbinded when closing the dialog.
      */
     function InitKeyEvent(CloseOnEscape) {
         var $Dialog = $('div.Dialog:visible');
@@ -128,13 +81,13 @@ Core.UI.Dialog = (function (TargetNS) {
          * to prevent the default action for the special keys.
          * See http://www.quirksmode.org/dom/events/keys.html for details
          */
-        $(document).off('keypress.Dialog').on('keypress.Dialog', function (Event) {
+        $(document).unbind('keypress.Dialog').bind('keypress.Dialog', function (Event) {
             if ($.browser.opera && (Event.keyCode === 9 || (Event.keyCode === 27 && CloseOnEscape))) {
                 Event.preventDefault();
                 Event.stopPropagation();
                 return false;
             }
-        }).off('keydown.Dialog').on('keydown.Dialog', function (Event) {
+        }).unbind('keydown.Dialog').bind('keydown.Dialog', function (Event) {
             var $Tabbables, $First, $Last;
 
             // Tab pressed
@@ -142,7 +95,7 @@ Core.UI.Dialog = (function (TargetNS) {
                 // :tabbable probably comes from jquery UI
                 $Tabbables = $('a:visible, input:visible, textarea:visible, select:visible, button:visible', $Dialog);
                 $First = $Tabbables.filter(':first');
-                $Last = $Tabbables.filter(':last');
+                $Last  = $Tabbables.filter(':last');
 
                 if (Event.target === $Last[0] && !Event.shiftKey) {
                     $First.focus(1);
@@ -167,95 +120,45 @@ Core.UI.Dialog = (function (TargetNS) {
         });
     }
 
-    /**
-     * @private
-     * @name DefaultSubmitFunction
-     * @memberof Core.UI.Dialog
-     * @function
-     * @description
-     *      The default submit function in the dialog.
-     */
     function DefaultSubmitFunction() {
         $('.Dialog:visible form').submit();
     }
 
-    /**
-     * @private
-     * @name DefaultCloseFunction
-     * @memberof Core.UI.Dialog
-     * @function
-     * @description
-     *      The default function to close the dialog.
-     */
     function DefaultCloseFunction() {
         TargetNS.CloseDialog($('.Dialog:visible'));
     }
 
     /**
-     * @name ShowDialog
-     * @memberof Core.UI.Dialog
      * @function
-     * @param {Object} Params - The different config options.
-     * @param {Boolean} Params.Modal - Shows a dark background overlay behind the dialog (default: false)
-     * @param {String} Params.Type - Alert|Search (default: undefined) Defines a special type of dialog.
-     * @param {String} Params.Title - Defines the title of the dialog window (default: undefined).
-     * @param {String} Params.Headline - Defines a special headline within the dialog window (default: undefined).
-     * @param {String} Params.Text - The text which is outputtet in the dialog window (default: undefined).
-     * @param {String} Params.HTML - Used for content dialog windows. Contains a complete HTML snippet or an jQuery object with containing HTML (default: undefined).
-     * @param {Number} Params.PositionTop - Defines the top position of the dialog window (default: undefined).
-     * @param {Number} Params.PositionBottom - Defines the bottom position of the dialog window (default: undefined).
-     * @param {Number|String} Params.PositionLeft - Defines the left position of the dialog window. 'Center' centers the window (default: undefined).
-     * @param {Number} Params.PositionRight - Defines the right position of the dialog window (default: undefined).
-     * @param {Boolean} Params.CloseOnClickOutside - If true, clicking outside the dialog closes the dialog (default: false).
-     * @param {Boolean} Params.CloseOnEscape - If true, pressing escape key closes the dialog (default: false).
-     * @param {Boolean} Params.AllowAutoGrow - If true, the InnerContent of the dialog can resize until the max window height is reached, if false (default), InnerContent of small dialogs does not resize over 200px.
-     * @param {Boolean} Params.HideHeader - Hide the header by setting this to true
-     * @param {Boolean} Params.HideFooter - Hide the footer by setting this to true
-     * @param {Object} Params.Buttons - Array of Hashes with the following properties (buttons are placed in a div "footer" of the dialog):
-     * @param {String} Params.Buttons.Label - Text of the button.
-     * @param {String} Params.Buttons.Type - 'Submit'|'Close' (default: none) Special type of the button - invokes a standard function.
-     * @param {String} Params.Buttons.Class - Optional class parameters for the button element.
-     * @param {Function} Params.Buttons.Function - The function which is executed on click (optional).
-     * @description
-     *      The main dialog function used for all different types of dialogs.
+     * @param Params Hash with different config options:
+     *               Modal: true|false (default: false) Shows a dark background overlay behind the dialog
+     *               Type: Alert|Search (default: undefined) Defines a special type of dialog
+     *               Title: string (default: undefined) Defines the title of the dialog window
+     *               Headline: string (default: undefined) Defines a special headline within the dialog window
+     *               Text: string (default: undefined) The text which is outputtet in the dialog window
+     *               HTML: string (default: undefined) Used for content dialog windows. Contains a complete HTML snippet or an jQuery object with containing HTML
+     *               PositionTop: value (default: undefined) Defines the top position of the dilaog window
+     *               PositionBottom: value (default: undefined) Defines the bottom position of the dilaog window
+     *               PositionLeft: value|Center (default: undefined) Defines the left position of the dilaog window. Center centers the window
+     *               PositionRight: value (default: undefined) Defines the right position of the dilaog window
+     *               CloseOnClickOutside true|false (default: false) If true, clicking outside the dialog closes the dialog
+     *               CloseOnEscape true|false (default: false) If true, pressing escape key closes the dialog
+     *               NotDraggableIE7: true|false (default: false) If true, the dialog is not draggable in IE7 (due to performance reasons)
+     *               Buttons: Array of Hashes with the following properties (buttons are placed in a div "footer" of the dialog):
+     *                  Label: string Text of the button
+     *                  Type: string 'Submit'|'Close' (default: none) Special type of the button - invokes a standard function
+     *                  Class: string Optional class parameters for the button element
+     *                  Function: function The function which is executed on click (optional)
+     * @return nothing
+     * @description The main dialog function used for all different types of dialogs.
      */
     TargetNS.ShowDialog = function(Params) {
-
-        var $Dialog, $Content, $ButtonFooter, HTMLBackup, DialogCopy, DialogCopySelector,
-            DialogHTML,
-            FullsizeMode = false;
-
-        DialogHTML = '<div class="Dialog">';
-        if (!Params.HideHeader) {
-            DialogHTML += '<div class="Header"><a class="Close" title="' + Core.Language.Translate('Close this dialog') + '" href="#"><i class="fa fa-times"></i></a></div>';
-        }
-        DialogHTML += '<div class="Content"></div>';
-        if (!Params.HideFooter) {
-            DialogHTML += '<div class="Footer"></div>';
-        }
-        DialogHTML += '</div>';
-
-        /**
-         * @private
-         * @name HandleClosingAction
-         * @memberof Core.UI.Dialog.ShowDialog
-         * @function
-         * @description
-         *      If no callback function for the close is given (via the Button definition),
-         *      the dialog is just closed. Otherwise the defined Close button is triggered,
-         *      which invokes the callback and the closing of the dialog.
-         */
+        // If no callback function for the close is given (via the Button definition),
+        // the dialog is just closed
+        // otherwise the defined Close button is triggered
+        // this invokes the callback and the closing of the dialog
         function HandleClosingAction() {
             var $CloseButton = $('.Dialog:visible button.Close');
-
-            // publish close event
-            Core.App.Publish('Event.UI.Dialog.CloseDialog.Close', [$Dialog]);
-
-            // Hide any possibly existing tooltips.
-            if (Core.Form && Core.Form.ErrorTooltips) {
-                Core.Form.ErrorTooltips.HideTooltip();
-            }
-
             if ($CloseButton.length) {
                 $CloseButton.trigger('click');
             }
@@ -264,17 +167,8 @@ Core.UI.Dialog = (function (TargetNS) {
             }
         }
 
-        /**
-         * @private
-         * @name CalculateDialogPosition
-         * @memberof Core.UI.Dialog.ShowDialog
-         * @function
-         * @returns {String} The position of the dialog.
-         * @param {String|Number} Position - The position of the dialog.
-         * @param {String} Type - Can be 'top' or 'bottom'.
-         * @description
-         *      Calculates the correct position of the dialog, given by the Position.
-         */
+        // Calculates the correct position of the dialog, given by the Position
+        // Type can be 'top' or 'bottom'
         function CalculateDialogPosition(Position, Type) {
             var ScrollTop = $(window).scrollTop(),
                 WindowHeight = $(window).height();
@@ -308,7 +202,8 @@ Core.UI.Dialog = (function (TargetNS) {
             return (Position + 'px');
         }
 
-        Core.App.Publish('Event.UI.Dialog.ShowDialog.BeforeOpen');
+        var $Dialog, $Content, $ButtonFooter, ContentScrollHeight, HTMLBackup, DialogCopy, DialogCopySelector, $InnerContent, InnerContentWidth = 0,
+            DialogHTML = '<div class="Dialog"><div class="Header"><a class="Close" title="' + Core.Config.Get('DialogCloseMsg') + '" href="#"></a></div><div class="Content"></div><div class="Footer"></div></div>';
 
         // Close all opened dialogs
         if ($('.Dialog:visible').length) {
@@ -330,12 +225,6 @@ Core.UI.Dialog = (function (TargetNS) {
         // Build Dialog HTML
         $Dialog = $(DialogHTML);
 
-        // Add responsive functionality
-        if (Core.App.Responsive.IsSmallerOrEqual(Core.App.Responsive.GetScreenSize(), 'ScreenL')) {
-            FullsizeMode = true;
-            $Dialog.addClass('Fullsize');
-        }
-
         if (Params.Modal) {
             $Dialog.addClass('Modal');
         }
@@ -345,7 +234,7 @@ Core.UI.Dialog = (function (TargetNS) {
         if (Params.HTML) {
             // If the data is a string, this is created dynamically or was delivered via AJAX.
             // But if the data is a jQueryObject, that means, that the prepared HTML code for the dialog
-            // was originally put as part of the tt into the HTML page
+            // was originally put as part of the DTL into the HTML page
             // For compatibility reasons (no double IDs etc.) we have to cut out the dialog HTML and
             // only use it for the dialog itself.
             // After the dialog is closed again we have to revert this cut-out, because otherwise we
@@ -359,13 +248,11 @@ Core.UI.Dialog = (function (TargetNS) {
                 // First get the data structure, ehich is (perhaps) already saved
                 // If the data does not exists Core.Data.Get returns an empty hash
                 DialogCopy = Core.Data.Get($('body'), 'DialogCopy');
-                DialogCopySelector = Core.Data.Get($('body'), 'DialogCopySelector');
                 HTMLBackup = (Params.HTML)[0].innerHTML;
+                DialogCopySelector = Params.HTML.selector;
                 // Add the new HTML data to the data structure and save it to the document
-                DialogCopy[DialogCounter] = HTMLBackup;
-                DialogCopySelector[DialogCounter] = Params.HTML;
+                DialogCopy[DialogCopySelector] = HTMLBackup;
                 Core.Data.Set($('body'), 'DialogCopy', DialogCopy);
-                Core.Data.Set($('body'), 'DialogSelector', DialogCopySelector);
                 // Additionally, we save the selector as data on the dialog itself for later restoring
                 // Remove the original dialog template content from the page
                 Params.HTML.empty();
@@ -379,7 +266,7 @@ Core.UI.Dialog = (function (TargetNS) {
             $Dialog.addClass('Alert');
             $Dialog.attr("role", "alertdialog");
             $Content = $Dialog.find('.Content').append('<div class="InnerContent"></div>').find('.InnerContent');
-            $Content.append('<i class="fa fa-warning"></i>');
+            $Content.append('<span class="Icon"></span>');
             if (Params.Headline) {
                 $Content.append('<h2>' + Params.Headline + '</h2>');
             }
@@ -391,7 +278,7 @@ Core.UI.Dialog = (function (TargetNS) {
                 Type: 'Close',
                 Function: Params.OnClose
             }];
-            $Content.append('<div class="Center Spacing"><button type="button" id="DialogButton1" class="CallForAction Close"><span>' + Core.Language.Translate('OK') + '</span></button></div>');
+            $Content.append('<div class="Center Spacing"><button type="button" id="DialogButton1" class="Close">Ok</button></div>');
         }
         // Define different other types here...
         else if (Params.Type === 'Search') {
@@ -411,14 +298,14 @@ Core.UI.Dialog = (function (TargetNS) {
                 $Content.append('<div class="InnerContent"></div>').find('.InnerContent').append(Params.HTML);
                 $ButtonFooter = $('<div class="ContentFooter Center"></div>');
                 $.each(Params.Buttons, function (Index, Value) {
-                    var Classes = 'CallForAction';
+                    var Classes = '';
                     if (Value.Type === 'Close') {
-                        Classes += ' Close';
+                        Classes = 'Close';
                     }
                     if (Value.Class) {
                         Classes += ' ' + Value.Class;
                     }
-                    $ButtonFooter.append('<button id="DialogButton' + (Index - 0 + 1) + '" class="' + Classes + '" type="button"><span>' + Value.Label + '</span></button> ');
+                    $ButtonFooter.append('<button id="DialogButton' + (Index - 0 + 1) + '" ' + (Classes.length ? ('class="' + Classes + '" ') : '') + 'type="button">' + Value.Label + '</button>');
                 });
                 $ButtonFooter.appendTo($Content);
             }
@@ -431,7 +318,7 @@ Core.UI.Dialog = (function (TargetNS) {
 
         // If Title is defined, add dialog title
         if (Params.Title) {
-            $Dialog.children('div.Header').append('<h1>' + Params.Title + '</h1>');
+            $Dialog.find('.Header').append('<h1>' + Params.Title + '</h1>');
         }
 
         // Add Dialog to page
@@ -441,19 +328,24 @@ Core.UI.Dialog = (function (TargetNS) {
         if ($Dialog.find('.Content .ContentFooter').length) {
             // change default Footer
             $Dialog.find('.Footer').addClass('ContentFooter');
+            // add special css for IE7
+            if ($.browser.msie && $.browser.version >= 7 && $.browser.version < 9) {
+                $InnerContent = $Dialog.find('.Content .InnerContent');
+                InnerContentWidth = $InnerContent.width() + parseInt($InnerContent.css('padding-left'), 10) + parseInt($InnerContent.css('padding-right'), 10);
+                $Dialog.find('.Content .ContentFooter').width(InnerContentWidth);
+            }
         }
 
-        // Now add the dialog number to the dialog data to restore the HTML later
-        Core.Data.Set($Dialog, 'DialogCounter', DialogCounter);
-        // Increase the dialog number for the next possible dialog
-        DialogCounter++;
-
+        // Now add the selector for the original dialog template content to the dialog, if it exists
+        if (DialogCopySelector && DialogCopySelector.length) {
+            Core.Data.Set($Dialog, 'DialogCopySelector', DialogCopySelector);
+        }
 
         // Set position for Dialog
         if (Params.Type === 'Alert') {
             $Dialog.css({
-                top: $(window).scrollTop() + ($(window).height() * 0.3),
-                left: Math.round(($(window).width() - $Dialog.width()) / 2)
+                top:    $(window).scrollTop() + ($(window).height() * 0.3),
+                left:   Math.round(($(window).width() - $Dialog.width()) / 2)
             });
         }
 
@@ -476,32 +368,13 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Check window height and adjust the scrollable height of InnerContent
-        AdjustScrollableHeight(Params.AllowAutoGrow);
+        AdjustScrollableHeight();
 
-        // Adjust dialog position on mobile devices
-        if (FullsizeMode) {
-            $Dialog.css('top', $(window).scrollTop());
-        }
-
-        // Add event-handling, not allowed on mobile devices
-        if (!FullsizeMode) {
+        // Add event-handling
+        if (!(Params.NotDraggableIE7 && $.browser.msie && parseInt($.browser.version, 10) === 7)) {
             $Dialog.draggable({
                 containment: 'body',
-                handle: '.Header',
-                start: function() {
-                    // Fire PubSub event for dragstart
-                    // (to handle more dependencies in their own namespaces)
-                    Core.App.Publish('Event.UI.Dialog.ShowDialog.DragStart', $Dialog);
-
-                    // Hide any possibly existing tooltips as they will not be moved
-                    //  with this dialog.
-                    if (Core.Form && Core.Form.ErrorTooltips) {
-                        Core.Form.ErrorTooltips.HideTooltip();
-                    }
-                },
-                stop: function() {
-                    Core.App.Publish('Event.UI.Dialog.ShowDialog.DragStop', $Dialog);
-                }
+                handle: '.Header'
             });
         }
 
@@ -546,7 +419,7 @@ Core.UI.Dialog = (function (TargetNS) {
 
         // Add CloseOnClickOutside functionality
         if (Params.CloseOnClickOutside) {
-            $(document).off('click.Dialog').on('click.Dialog', function (event) {
+            $(document).unbind('click.Dialog').bind('click.Dialog', function (event) {
                 // If target element is removed before this event triggers, the enclosing div.Dialog can't be found anymore
                 // We check, if we can find a parent HTML element to be sure, that the element is not removed
                 if ($(event.target).parents('html').length && $(event.target).closest('div.Dialog').length === 0) {
@@ -556,43 +429,31 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Add resize event handler for calculating the scroll height
-        $(window).off('resize.Dialog').on('resize.Dialog', function () {
-            AdjustScrollableHeight(Params.AllowAutoGrow);
-        });
-
-        Core.App.Subscribe('Event.App.Responsive.SmallerOrEqualScreenL', function () {
-            // Dialog should be fullsize, if on smaller screens
-            $Dialog.addClass('Fullsize');
-        });
-
-        Core.App.Subscribe('Event.App.Responsive.ScreenXL', function () {
-            $Dialog.removeClass('Fullsize');
+        $(window).unbind('resize.Dialog').bind('resize.Dialog', function (event) {
+            AdjustScrollableHeight();
         });
 
         // Init KeyEvent-Logger
         InitKeyEvent(Params.CloseOnEscape);
 
-        Core.UI.InputFields.Activate($Dialog);
-
         // Focus first focusable element
         FocusFirstElement();
     };
 
     /**
-     * @name ShowContentDialog
-     * @memberof Core.UI.Dialog
      * @function
-     * @param {String} HTML - The content HTML which should be shown.
-     * @param {String} Title - The title of the dialog.
-     * @param {Number|String} PositionTop - The top position the dialog is positioned initially.
-     * @param {Numer|String} PositionLeft - The left position the dialog is positioned initially.
-     * @param {Boolean} Modal - If defined and set to true, an overlay is shown for a modal dialog.
-     * @param {Array} Buttons - The button array.
-     * @param {Boolean} AllowAutoGrow - If true, the InnerContent of the dialog can resize until the max window height is reached, if false (default), InnerContent of small dialogs does not resize over 200px.
      * @description
      *      Shows a default dialog.
+     * @param HTML The content HTML which should be shown
+     * @param Title The title of the dialog
+     * @param PositionTop The top position the dialog is positioned initially
+     * @param PositionLeft The left position the dialog is positioned initially
+     * @param Modal If defined and set to true, an overlay is shown for a modal dialog
+     * @param Buttons The button array
+     * @param NotDraggableIE7 If true, the dialog is not draggable in IE7 (performance reasons)
+     * @return nothing
      */
-    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, AllowAutoGrow) {
+    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, NotDraggableIE7) {
         TargetNS.ShowDialog({
             HTML: HTML,
             Title: Title,
@@ -602,61 +463,18 @@ Core.UI.Dialog = (function (TargetNS) {
             PositionTop: PositionTop,
             PositionLeft: PositionLeft,
             Buttons: Buttons,
-            AllowAutoGrow: AllowAutoGrow
+            NotDraggableIE7: NotDraggableIE7
         });
     };
 
     /**
-     * @name ShowWaitingDialog
-     * @memberof Core.UI.Dialog
-     * @function
-     * @param {String} Title - The title of the dialog.
-     * @param {String} Text - The text of the dialog.
-     * @description
-     *      Shows a waiting dialog (with spinner icon) and customizable title and text
-     */
-    TargetNS.ShowWaitingDialog = function (Title, Text) {
-
-        var DialogTemplate = Core.Template.Render('Dialog/Waiting', {
-            Text: Text
-        });
-
-        TargetNS.ShowDialog({
-            HTML: DialogTemplate,
-            Title: Title,
-            Modal: true,
-            CloseOnClickOutside: false,
-            CloseOnEscape: false,
-            PositionTop: '20%',
-            PositionLeft: 'Center',
-            AllowAutoGrow: true,
-            HideHeader: true,
-            HideFooter: true
-        });
-    };
-
-    /**
-     * @name MakeDialogWait
-     * @memberof Core.UI.Dialog
      * @function
      * @description
-     *      Shows a spinner overlay on the currently visible modal dialog. Is meant for showing the user that something is about
-     *      to happen, e.g. if changing a field within a dialog causes a page reload.
-     */
-    TargetNS.MakeDialogWait = function () {
-        $('.Dialog:visible .InnerContent').prepend('<div class="Waiting"><i class="fa fa-spinner fa-spin"></i></div>').find('.Waiting').fadeIn();
-    };
-
-    /**
-     * @name ShowAlert
-     * @memberof Core.UI.Dialog
-     * @function
-     * @param {String} Headline - The bold headline text.
-     * @param {String} Text - The description.
-     * @param {Function} CloseFunction - The special function which is started on closing the dialog
-     *                                   (optional, if used also the removing of the dialog itself must be handled).
-     * @description
-     *      Shows an alert dialog.
+     *      Shows a alert dialog.
+     * @param Headline The bold headline
+     * @param Text The description
+     * @param CloseFunction The special function which is started on closing the dialog (optional, if used also the removing of the dialog itself must be handled)
+     * @return nothing
      */
     TargetNS.ShowAlert = function (Headline, Text, CloseFunction) {
         TargetNS.ShowDialog({
@@ -669,22 +487,25 @@ Core.UI.Dialog = (function (TargetNS) {
     };
 
     /**
-     * @name CloseDialog
-     * @memberof Core.UI.Dialog
      * @function
-     * @param {jQueryObject} Object - The jQuery object that defines the dialog or any child element of it, which should be closed.
      * @description
      *      Closes all dialogs specified.
+     * @param Object The jQuery object that defines the dialog or any child element of it, which should be closed
+     * @return nothing
      */
     TargetNS.CloseDialog = function (Object) {
-        var $Dialog, $DialogSelector, DialogCopy, DialogSelectorData, InternalDialogCounter, BackupHTML;
+        function ResetRTE(Editor) {
+            CKEDITOR.instances[Editor].setMode('source');
+            window.setTimeout(function () {
+                CKEDITOR.instances[Editor].setMode('wysiwyg');
+            }, 100);
+        }
+
+        var $Dialog, DialogCopy, DialogCopySelector, BackupHTML, Editor;
         $Dialog = $(Object).closest('.Dialog:visible');
 
-        // Get the original dialog number for the content template
-        InternalDialogCounter = Core.Data.Get($Dialog, 'DialogCounter');
-
-        // publish close event
-        Core.App.Publish('Event.UI.Dialog.CloseDialog.Close', [$Dialog]);
+        // Get the original selector for the content template
+        DialogCopySelector = Core.Data.Get($Dialog, 'DialogCopySelector');
 
         $Dialog.remove();
         $('#Overlay').remove();
@@ -696,27 +517,40 @@ Core.UI.Dialog = (function (TargetNS) {
         $('body').css('min-height', 'auto');
 
         // Revert orignal html
-        if (InternalDialogCounter) {
+        if (DialogCopySelector.length) {
             DialogCopy = Core.Data.Get($('body'), 'DialogCopy');
-            DialogSelectorData = Core.Data.Get($('body'), 'DialogSelector');
             // Get saved HTML
             if (typeof DialogCopy !== 'undefined') {
-                BackupHTML = DialogCopy[InternalDialogCounter];
-                $DialogSelector = DialogSelectorData[InternalDialogCounter];
+                BackupHTML = DialogCopy[DialogCopySelector];
 
                 // If HTML could be restored, write it back into the page
                 if (BackupHTML && BackupHTML.length) {
-                    $DialogSelector.append(BackupHTML);
+                    $(DialogCopySelector).append(BackupHTML);
                 }
 
                 // delete this variable from the object
-                delete DialogCopy[InternalDialogCounter];
-                delete DialogSelectorData[InternalDialogCounter];
+                delete DialogCopy[DialogCopySelector];
             }
 
             // write the new DialogCopy back
             Core.Data.Set($('body'), 'DialogCopy', DialogCopy);
         }
+
+        // Repair all existing rich text editors
+        // in Firefox/Linux and IE/Win the editor is not usable anymore after a OTRS dialog was opened
+        // This workaround fixes this, because opening the wysiwyg again reloads the editor.
+        if (typeof CKEDITOR !== 'undefined') {
+            for (Editor in CKEDITOR.instances) {
+                if (typeof CKEDITOR.instances[Editor].setMode === 'function') {
+                    window.setTimeout(ResetRTE, 0, Editor);
+                }
+            }
+        }
+
+        // Workaround for bug#6060 - In IE7, input elements can't get focus anymore after opening dialog
+        // giving focus automatically solves the problem
+        $('input:text:first').focus().blur();
+
     };
 
     return TargetNS;
